;; Generated package description from minibuffer-header.el  -*- no-byte-compile: t -*-
(define-package "minibuffer-header" "0.5.0.20220809.81013" "Minibuffer header line" '((emacs "27.1")) :commit "fe5d90d3f13c0010eed3b5dd437b458f8bf3da5f" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("convenience") :url "https://github.com/rougier/minibuffer-header")
